@@ -27,7 +27,7 @@ class Attachment(AbstractModel):
         r"""
         :param FileName: 附件名称，最大支持255个字符长度，不支持部分附件类型，详情请参考[附件类型](https://cloud.tencent.com/document/product/1288/51951)。
         :type FileName: str
-        :param Content: base64之后的附件内容，您可以发送的附件大小上限为4 MB。 注意：腾讯云api目前要求请求包大小不得超过8 MB。如果您要发送多个附件，那么这些附件的总大小不能超过8 MB。
+        :param Content: Base64之后的附件内容，你可以发送的附件大小上限为4M。注意：腾讯云接口请求最大支持 8M 的请求包，附件内容经过 Base64 预期扩大1.5倍。应该控制所有附件的总大小最大在 4M 以内，整体请求超出 8M 接口会返回错误。
         :type Content: str
         """
         self.FileName = None
@@ -54,8 +54,8 @@ class BatchSendEmailRequest(AbstractModel):
     def __init__(self):
         r"""
         :param FromEmailAddress: 发信邮件地址。请填写发件人邮箱地址，例如：noreply@mail.qcloud.com。如需填写发件人说明，请按照
-发信人 <邮件地址> 的方式填写，例如：
-腾讯云团队 <noreply@mail.qcloud.com>
+发信人 &lt;邮件地址&gt; 的方式填写，例如：
+腾讯云团队 &lt;noreply@mail.qcloud.com&gt;
         :type FromEmailAddress: str
         :param ReceiverId: 收件人列表ID
         :type ReceiverId: int
@@ -386,7 +386,7 @@ class CreateReceiverDetailWithDataRequest(AbstractModel):
         r"""
         :param ReceiverId: 收件人列表ID
         :type ReceiverId: int
-        :param Datas: 收信人邮箱以及模板参数，数组形式
+        :param Datas: 收信人邮箱以及模板参数，数组形式。收件人个数限制20000个以内。
         :type Datas: list of ReceiverInputData
         """
         self.ReceiverId = None
@@ -487,14 +487,18 @@ class CycleEmailParam(AbstractModel):
         :type BeginTime: str
         :param IntervalTime: 任务周期 小时维度
         :type IntervalTime: int
+        :param TermCycle: 是否终止周期，用于任务更新 0否1是
+        :type TermCycle: int
         """
         self.BeginTime = None
         self.IntervalTime = None
+        self.TermCycle = None
 
 
     def _deserialize(self, params):
         self.BeginTime = params.get("BeginTime")
         self.IntervalTime = params.get("IntervalTime")
+        self.TermCycle = params.get("TermCycle")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -762,16 +766,24 @@ class EmailIdentity(AbstractModel):
         :type IdentityType: str
         :param SendingEnabled: 是否已通过验证
         :type SendingEnabled: bool
+        :param CurrentReputationLevel: 当前信誉等级
+        :type CurrentReputationLevel: int
+        :param DailyQuota: 当日最高发信量
+        :type DailyQuota: int
         """
         self.IdentityName = None
         self.IdentityType = None
         self.SendingEnabled = None
+        self.CurrentReputationLevel = None
+        self.DailyQuota = None
 
 
     def _deserialize(self, params):
         self.IdentityName = params.get("IdentityName")
         self.IdentityType = params.get("IdentityType")
         self.SendingEnabled = params.get("SendingEnabled")
+        self.CurrentReputationLevel = params.get("CurrentReputationLevel")
+        self.DailyQuota = params.get("DailyQuota")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -906,10 +918,16 @@ class GetEmailTemplateResponse(AbstractModel):
         r"""
         :param TemplateContent: 模板内容数据
         :type TemplateContent: :class:`tencentcloud.ses.v20201002.models.TemplateContent`
+        :param TemplateStatus: 模板状态 0-审核通过 1-待审核 2-审核拒绝
+        :type TemplateStatus: int
+        :param TemplateName: 模板名称
+        :type TemplateName: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.TemplateContent = None
+        self.TemplateStatus = None
+        self.TemplateName = None
         self.RequestId = None
 
 
@@ -917,6 +935,8 @@ class GetEmailTemplateResponse(AbstractModel):
         if params.get("TemplateContent") is not None:
             self.TemplateContent = TemplateContent()
             self.TemplateContent._deserialize(params.get("TemplateContent"))
+        self.TemplateStatus = params.get("TemplateStatus")
+        self.TemplateName = params.get("TemplateName")
         self.RequestId = params.get("RequestId")
 
 
@@ -1176,10 +1196,16 @@ class ListEmailIdentitiesResponse(AbstractModel):
         r"""
         :param EmailIdentities: 发信域名列表
         :type EmailIdentities: list of EmailIdentity
+        :param MaxReputationLevel: 最大信誉等级
+        :type MaxReputationLevel: int
+        :param MaxDailyQuota: 单域名最高日发送量
+        :type MaxDailyQuota: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.EmailIdentities = None
+        self.MaxReputationLevel = None
+        self.MaxDailyQuota = None
         self.RequestId = None
 
 
@@ -1190,6 +1216,8 @@ class ListEmailIdentitiesResponse(AbstractModel):
                 obj = EmailIdentity()
                 obj._deserialize(item)
                 self.EmailIdentities.append(obj)
+        self.MaxReputationLevel = params.get("MaxReputationLevel")
+        self.MaxDailyQuota = params.get("MaxDailyQuota")
         self.RequestId = params.get("RequestId")
 
 
@@ -1443,7 +1471,7 @@ class ReceiverInputData(AbstractModel):
         :param Email: 收件人邮箱
         :type Email: str
         :param TemplateData: 模板中的变量参数，请使用json.dump将json对象格式化为string类型。该对象是一组键值对，每个Key代表模板中的一个变量，模板中的变量使用{{键}}表示，相应的值在发送时会被替换为{{值}}。
-注意：参数值不能是html等复杂类型的数据。
+注意：参数值不能是html等复杂类型的数据。TemplateData (整个 JSON 结构) 总长度限制为 800 bytes。
         :type TemplateData: str
         """
         self.Email = None
@@ -1479,11 +1507,11 @@ class SendEmailRequest(AbstractModel):
         :type Subject: str
         :param ReplyToAddresses: 邮件的“回复”电子邮件地址。可以填写您能收到邮件的邮箱地址，可以是个人邮箱。如果不填，收件人的回复邮件将会发送失败。
         :type ReplyToAddresses: str
-        :param Template: 使用模板发送时，填写的模板相关参数
+        :param Template: 使用模板发送时，填写的模板相关参数。因 Simple 已经废除使用，Template 为必填项
         :type Template: :class:`tencentcloud.ses.v20201002.models.Template`
         :param Simple: 已废弃
         :type Simple: :class:`tencentcloud.ses.v20201002.models.Simple`
-        :param Attachments: 需要发送附件时，填写附件相关参数。
+        :param Attachments: 需要发送附件时，填写附件相关参数。腾讯云接口请求最大支持 8M 的请求包，附件内容经过 Base64 预期扩大1.5倍，应该控制所有附件的总大小最大在 4M 以内，整体请求超出 8M 时接口会返回错误
         :type Attachments: list of Attachment
         :param Unsubscribe: 退订选项 1: 加入退订链接 0: 不加入退订链接
         :type Unsubscribe: str
@@ -1573,12 +1601,14 @@ class SendEmailStatus(AbstractModel):
 1005: 内部系统异常
 1006: 触发频率控制，短时间内对同一地址发送过多邮件
 1007: 邮件地址在黑名单中
+1008: 域名被收件人拒收
 1009: 内部系统异常
 1010: 超出了每日发送限制
 1011: 无发送自定义内容权限，必须使用模板
+1013: 域名被收件人取消订阅
 2001: 找不到相关记录
 3007: 模板ID无效或者不可用
-3008: 模板状态异常
+3008: 被收信域名临时封禁
 3009: 无权限使用该模板
 3010: TemplateData字段格式不正确 
 3014: 发件域名没有经过认证，无法发送
